const path = require('path');
const exec = require('child_process').exec;
const glob = require('glob');
const fs = require('fs');
const async = require('async');

const extractor = require('./src/extractor');
const transformer = require('./src/html-transformer');

module.exports = function extract(pathToFile, options) {
  if (!pathToFile) {
    throw new Error('keynote-extract requires a file to operate on.');
  }

  if (path.parse(pathToFile).ext !== '.key') {
    throw new Error('The file passed to keynote-extract is not a Keynote presentation.');
  }

  if (!options.outputPath) {
    throw new Error('`options.outputPath` needs to be a valid path.');
  }

  return new Promise(function (resolve, reject) {
    async.series([
      // Remove tmp directory
      function (callback) {
        exec(`rm -rf /tmp/keynote-extractor/`, function (err) {
          callback(err);
        });
      },
      // Extract
      function (callback) {
        extractor.extract(pathToFile).then(function () {
          callback(null);
        });
      },
      // Transform HTML
      function (callback) {
        transformer.transform();
        callback();
      },
      // Sync extracted HTML/images to output path
      function (callback) {
        exec(`rsync -a /tmp/keynote-extractor/output/* ${options.outputPath}`);
        callback();
      },
    ], function () {
      resolve();
    })
  });
};
