const fs = require('fs');
const path = require('path');
const async = require('async');
const exec = require('child_process').exec;
const extractNotes = require('./notes-extractor');

const scriptsLocation = path.join(__dirname, '../applescripts');

const exportImagesScriptLocation = path.join(scriptsLocation, 'export-images.applescript');
const exportKeynote09ScriptLocation = path.join(scriptsLocation, 'export-to-keynote-09.applescript');
const closeDocumentScriptLocation = path.join(scriptsLocation, 'close-document.applescript');

module.exports = {
  extract: function (pathToFile) {
    return new Promise(function (resolve, reject) {
      async.series([
        // Extract images
        function (callback) {
          exec(`osascript ${exportImagesScriptLocation} "${pathToFile}" "keynote-extractor"`, function (err) {
            callback(err);
          });
        },
        // Extract presentation to Keynote 09 format
        function (callback) {
          exec(`osascript ${exportKeynote09ScriptLocation} "${pathToFile}" "keynote-extractor"`, function (err) {
            callback(err);
          });
        },
        // Close document in Keynote and quit if necessary
        function (callback) {
          exec(`osascript ${closeDocumentScriptLocation}`, function (err) {
            callback(err);
          });
        },
        // Rename presentation to zip
        function (callback) {
          exec(`mv /tmp/keynote-extractor/keynote-extractor.key /tmp/keynote-extractor/keynote-extractor.zip`, function (err) {
            callback(err);
          });
        },
        // Extract presentation archive to extracted directory
        function (callback) {
          exec(`unzip /tmp/keynote-extractor/keynote-extractor.zip -d /tmp/keynote-extractor/extracted`, function (err) {
            callback(err);
          });
        },
        // Take the index.apxl file out of the extracted content
        function (callback) {
          exec(`mv /tmp/keynote-extractor/extracted/index.apxl /tmp/keynote-extractor/`, function (err) {
            callback(err);
          });
        },
        // Extract notes
        function (callback) {
          fs.readFile(`/tmp/keynote-extractor/index.apxl`, function (err, contents) {
            const extractedNotes = extractNotes(contents.toString());
            const html = `
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
</head>
<body>
  ${extractedNotes}
</body>
</html>
    `;
            fs.writeFile(`/tmp/keynote-extractor/extracted.html`, html, function () {
              callback();
            });
          });
        },
      ], function () {
        resolve();
      });
    });
  }
};
