const cheerio = require('cheerio');
const beautifyHtml = require('js-beautify').html;

const STYLE_CODES = {
  BOLD: '15',
  ITALIC: '17',
  UNDERLINED: '18',
};

module.exports = function (xml) {
  const $ = cheerio.load(xml);

  const html = $('key\\:slide-list key\\:slide')
    .filter(function () {
      return $(this).attr('key:hidden') !== 'true';
    })
    .map(function () {
      const $notesBody = $(this)
        .find('key\\:notes sf\\:text-body')
        .find('sf\\:p')
          .replaceWith(function () {
            $(this).find('sf\\:br').remove();
            const isEmpty = !$(this).html().trim();

            if (isEmpty) {
              $(this).remove();
            } else {
              return `<p>${$(this).html()}</p>`;
            }
          })
        .end()
        .find('sf\\:link')
          .replaceWith(function () {
            const url = $(this).attr('href');
            const text = $(this).text().trim();
            return `<a href="${url}" target="_blank">${text}</a>`;
          })
        .end()
        .find('sf\\:span')
          .replaceWith(function () {
            const style = $(this).attr('sf:style').replace('sf:characterstyle-', '');
            const text = $(this).text().trim();

            switch (style) {
              case STYLE_CODES.BOLD:
                return `<strong>${text}</strong>`;
                break;
              case STYLE_CODES.ITALIC:
                return `<em>${text}</em>`;
                break;
            }
          })
        .end();

      return `
<article>
  ${$notesBody.html()}
</article>
        `;
    })
    .get()
    .join('')
    .replace(/\n/g, '');

  return beautifyHtml(html, {
    indent_size: 2
  });
};